@@ -65,6 +65,8 @@ pub enum Error {
     StatusNotFound,
     #[error("solana hash parse {0}")]
     SolanaHashParse(#[from] solana_sdk::hash::ParseHashError),
+    #[error("solana network error")]
+    SolanaNetworkError,
     #[error("solana hash parse {0}")]
     TokioJoinError(#[from] tokio::task::JoinError),
     #[error("transaction is not signed")]
